class Mapping(object):

    RED = 0
    GREEN = 1
    BLUE = 2
    CHANNELS = 3

    def __init__(self):
        """create a new color mapping for an EtherPix distributor"""
        self._base = 0.0
        self._gamma = 1.0
        self._factor = 1.0
        self._precompute()

    def set_params(self, base, gamma, factor):
        """set mapping parameters"""
        self._base = base
        self._gamma = gamma
        self._factor = factor
        self._precompute()

    def _precompute(self):
        """pre-compute mapping table"""
        # display_value := base + factor * input_value ^ (1 / gamma)
        gamma_1 = 1.0 / self._gamma
        tab = []
        for v in range(256):
            val = self._base + self._factor * (v / 255.0) ** gamma_1
            if val < 0:
                tab.append(0)
            elif val > 1.0:
                tab.append(255)
            else:
                tab.append(int(round(val * 255.0)))
        self._table = tuple(tab)

